# -*- coding: utf-8 -*-

"""
EconoMe - Connecting your QGIS-Project with EconoMe.

Copyright (C) 2025 Federal Office for the Environment FOEN, Switzerland

Authors
  - Kevin Helzel (WSL Institute for Snow and Avalanche Research SLF, Davos, Switzerland)
  - Tobia Lezuo (Geotest AG, Davos, Switzerland)

Email
  - Plugin & Code: kevin.helzel@slf.ch
  - EconoMe project leader: linda.ettlin@slf.ch

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.

Generated by QGIS Plugin Builder: http://g-sherman.github.io/Qgis-Plugin-Builder/
"""

import os

from qgis.PyQt import uic
from qgis.PyQt import QtWidgets
from qgis.PyQt.QtGui import QIcon, QPixmap
from qgis.PyQt.QtCore import Qt


# This loads your .ui file so that PyQt can populate your plugin with the elements from Qt Designer
FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'econo_me_dialog_asset_handling.ui'))


class DamagePotentialMismatchResolveDialog(QtWidgets.QDialog, FORM_CLASS):
    def __init__(self, parent=None, mode = None, mismatch = None, main_dialog = None):
        super(DamagePotentialMismatchResolveDialog, self).__init__(parent)
        self.setupUi(self)

        # Dialog header
        self.setWindowTitle("SCHADENPOTENTIAL SYNCHRONISIEREN")
        self.setWindowIcon(QIcon(os.path.join(os.path.dirname(__file__), "icon.png")))
        self.labelScrollArea_message_text.setWordWrap(True)
        
        # Status icon
        self.plugin_dir = os.path.dirname(__file__)
        path_to_warning = os.path.join(self.plugin_dir + "\\general-icons", "warning.png")
        pixmap_warning = QPixmap(path_to_warning)
        scaled_pixmap_warning = pixmap_warning.scaled(
            main_dialog.IMAGE_LABEL_SCENARIO_STATUS_FREE.size(),
            Qt.KeepAspectRatio,
            Qt.SmoothTransformation)
        self.img_label.setPixmap(scaled_pixmap_warning)
        
        # avoid error none of the buttons is clicked and the dialog is closed
        self.selected_option = ""
        
        if mode == "MISMATCH":
            # set texts
            self.label_message_title.setText(f"Änderungen zusammenführen".upper())
            self.label_suptitle.setText(f"{len(mismatch.keys())} Schadenobjekte weisen Konflikte auf:")
            mismatch_text = ""
            for AssetIdentID, asset_mismatch_dict in mismatch.items():
                mismatch_text += f"{AssetIdentID}:\n"
                try:
                    # TODO: replace empty str/values with "leer"
                    # TODO: replace key with german translation
                    mismatch_text += "\n".join([f"    Attribut {key} ist in Layer {value['Layer']} und in EconoMe {value['API']}" for key, value in asset_mismatch_dict.items()]) + "\n"
                except:
                    mismatch_text += f"    {asset_mismatch_dict['Missing']}\n"
            self.labelScrollArea_message_text.setText(mismatch_text)
            self.label_question.setText("Welche Schadenobjekte sollen beibehalten werden?")
            self.button_opt1.setText("Layer-Objekte")
            self.label_opt1.setText("Überschreibt Objekt-Attribute in EconoMe.")
            self.button_opt2.setText("EconoMe-Objekte")
            self.label_opt2.setText("Überschreibt Objekt-Attribute im Layer.")
            
            # buttons and answer
            self.button_opt1.clicked.connect(self.keep_layer_assets)
            self.button_opt2.clicked.connect(self.keep_econome_assets)
        elif mode == "MISSING":
            # set texts
            self.label_message_title.setText(f"Änderungen zusammenführen".upper())
            self.label_suptitle.setText(f"{len(mismatch.keys())} Schadenobjekte fehlen im Layer:")
            
            mismatch_text = ""
            for AssetIdentID, asset_mismatch_dict in mismatch.items():
                mismatch_text += f"{AssetIdentID}:\n"
                mismatch_text += f"    {asset_mismatch_dict['Missing']}\n"
            self.labelScrollArea_message_text.setText('\n'.join(mismatch))
            self.label_question.setText("Was soll mit den diesen fehlenden Schadenobjekten passieren?")
            self.button_opt1.setText("Im EconoMe löschen")
            self.label_opt1.setText("Informationen gehen verloren.")
            self.button_opt2.setText("Keine Änderung")
            self.label_opt2.setText("Dann im Layer manuell hinzufügen.")
            
            # buttons and answer
            self.button_opt1.clicked.connect(self.delete_missing_assets)
            self.button_opt2.clicked.connect(self.no_change)
        
    def keep_layer_assets(self):
        self.selected_option = "KEEP LAYER ASSETS"
        self.accept()
    def keep_econome_assets(self):
        self.selected_option = "KEEP ECONOME ASSETS"
        self.accept()
    def delete_missing_assets(self):
        self.selected_option = "DELETE MISSING ASSETS"
        self.accept()
    def no_change(self):
        self.selected_option = "NO CHANGE"
        self.accept()